# coding: utf-8

"""
Code generated by OpenAPI Generator (https://openapi-generator.tech), manual changes will be lost - read more on https://github.com/algolia/api-clients-automation. DO NOT EDIT.
"""
from __future__ import annotations

from json import loads
from typing import Annotated, Any, Dict, Optional, Self

from pydantic import BaseModel, Field, StrictStr


class AbTestsVariantSearchParams(BaseModel):
    """
    AbTestsVariantSearchParams
    """

    index: StrictStr = Field(
        description="Index name of the A/B test variant (case-sensitive)."
    )
    traffic_percentage: Annotated[int, Field(le=100, strict=True, ge=0)] = Field(
        description="Percentage of search requests each variant receives.",
        alias="trafficPercentage",
    )
    description: Optional[StrictStr] = Field(
        default=None, description="Description for this variant."
    )
    custom_search_parameters: Dict[str, Any] = Field(alias="customSearchParameters")

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_json(self) -> str:
        return self.model_dump_json(by_alias=True, exclude_unset=True)

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AbTestsVariantSearchParams from a JSON string"""
        return cls.from_dict(loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={},
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AbTestsVariantSearchParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "index": obj.get("index"),
                "trafficPercentage": obj.get("trafficPercentage"),
                "description": obj.get("description"),
                "customSearchParameters": obj.get("customSearchParameters"),
            }
        )
        return _obj
